// 
// Copyright (C) 2007, NinjaTrader LLC <www.ninjatrader.com>.
// NinjaTrader reserves the right to modify or overwrite this NinjaScript component with each release.
//

#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Indicator;
using NinjaTrader.Strategy;
#endregion

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    /// <summary>
    /// Simple RSI cross over strategy.
    /// </summary>
    [Description("Simple multiple RSI/SMA cross over strategy.")]
    [Gui.Design.DisplayName("Sample Multiple Entry/Exit Signals")]
    public class SampleMultipleEntryExitSignals : Strategy
    {
        #region Variables
		private int		period		= 14;
		private int		smooth		= 3;
		private int		smaperiod 	= 5;
        #endregion

        /// <summary>
        /// This method is used to configure the strategy and is called once before any strategy method is called.
        /// </summary>
        protected override void Initialize()
        {
			// Add RSI and SMA indicators to the chart for display
			Add(RSI(RSI_Period, RSI_Smooth));
			Add(SMA(SMA_Period));
			
			// EntriesPerDirection sets the number of entries per direction allowed when there is an active position
			EntriesPerDirection = 1;
			
			/* EntryHandling determines how entry orders are handled by the EntriesPerDirection.
			If set to "EntryHandling.AllEntries", EntriesPerDirection will only allow the set amount of entries for all entries
			If set to "EntryHandling.UniqueEntries", EntriesPerDirection will allow up to the set amount of entries for each uniquely named entry. */
			EntryHandling = EntryHandling.AllEntries;
			
            CalculateOnBarClose = true;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			// Entry Signal 1: If RSI value crosses above 20
			if (CrossAbove(RSI(RSI_Period, RSI_Smooth), 20, 1))
			{
				// Placing a string between the parenthesis allows you to give unique identifiers to your entries.
				EnterLong("RSI Entry");
			}
			
			// Exit Signal 1: If RSI value crosses below 80
			if (CrossBelow(RSI(RSI_Period, RSI_Smooth), 80, 1))
				ExitLong("RSI Entry");
			
			// Entry Signal 2: If SMA crosses above the current close
			if (CrossAbove(SMA(SMA_Period), Close, 1))
				EnterLong("SMA Entry");
			
			// Exit Signal 2: If SMA crosses below the current close
			if (CrossBelow(SMA(SMA_Period), Close, 1))
				ExitLong("SMA Entry");
        }

        #region Properties
		/// <summary>
		/// </summary>
		[Description("Numbers of bars used for RSIcalculations")]
		[Category("Parameters")]
		public int RSI_Period
		{
			get { return period; }
			set { period = Math.Max(2, value); }
		}

		/// <summary>
		/// </summary>
		[Description("Number of bars for smoothing")]
		[Category("Parameters")]
		public int RSI_Smooth
		{
			get { return smooth; }
			set { smooth = Math.Max(1, value); }
		}
		
		/// <summary>
		/// </summary>
		[Description("Numbers of bars used for SMA calculations")]
		[Category("Parameters")]
		public int SMA_Period
		{
			get { return smaperiod; }
			set { smaperiod = Math.Max(1, value); }
		}
        #endregion
    }
}
